@@ -1,11 +1,20 @@
 import os
 import shutil
+import sys
 
 import click
 
+from aicrowd.notebook.exceptions import NotebookException
 from aicrowd.utils import AliasedGroup
 
 
+def print_exception(e: NotebookException):
+    click.echo(click.style(f"{type(e).__name__}: {e.message}", fg="red"))
+    if e.fix:
+        click.echo(click.style(e.fix, fg="yellow"))
+    sys.exit(e.exit_code)
+
+
 @click.group(name="notebook", cls=AliasedGroup)
 def notebook_command():
     """
@@ -32,7 +41,10 @@ def clean_subcommand(file: str):
     """
     from aicrowd.notebook.clean import clean_notebook
 
-    clean_notebook(file_path=file)
+    try:
+        clean_notebook(file_path=file)
+    except NotebookException as e:
+        print_exception(e)
 
 
 @click.command(name="split")
@@ -55,7 +67,10 @@ def split_subcommand(file: str, output_dir: str):
     """
     from aicrowd.notebook.split import split_notebook
 
-    split_notebook(file, output_dir)
+    try:
+        split_notebook(file, output_dir)
+    except NotebookException as e:
+        print_exception(e)
 
 
 @click.command(name="submit")
@@ -82,15 +97,18 @@ def submit_subcommand(
     """
     from aicrowd.notebook.submit import create_submission
 
-    create_submission(
-        challenge,
-        description,
-        assets_dir,
-        output,
-        notebook_name,
-        no_verify,
-        dry_run,
-    )
+    try:
+        create_submission(
+            challenge,
+            description,
+            assets_dir,
+            output,
+            notebook_name,
+            no_verify,
+            dry_run,
+        )
+    except NotebookException as e:
+        print_exception(e)
 
 
 @click.command(name="extract")
@@ -109,11 +127,14 @@ def extract_subcommand(file: str, start: str, end: str, remove: bool = False):
     from aicrowd.notebook.split import extract_partial_notebook
     from aicrowd.notebook.helpers import read_notebook, write_notebook
 
-    nb = read_notebook(file)
-    partial_nb = extract_partial_notebook(
-        nb=nb, start_block=start, end_block=end, remove=remove
-    )
-    write_notebook(file_path=os.path.join(os.getcwd(), file), nb=partial_nb)
+    try:
+        nb = read_notebook(file)
+        partial_nb = extract_partial_notebook(
+            nb=nb, start_block=start, end_block=end, remove=remove
+        )
+        write_notebook(file_path=os.path.join(os.getcwd(), file), nb=partial_nb)
+    except NotebookException as e:
+        print_exception(e)
 
 
 @click.command(name="copy")
@@ -128,9 +149,12 @@ def copy_subcommand(output: str, clean: bool = False):
     from aicrowd.notebook.helpers import get_notebook_path
     from aicrowd.notebook.clean import clean_notebook
 
-    shutil.copy2(get_notebook_path(), output)
-    if clean:
-        clean_notebook(output)
+    try:
+        shutil.copy2(get_notebook_path(), output)
+        if clean:
+            clean_notebook(output)
+    except NotebookException as e:
+        print_exception(e)
 
 
 notebook_command.add_command(clean_subcommand)
