@@ -28,4 +28,11 @@ class CLIException(Exception):
         self.exit_code = exit_code
 
     def __repr__(self):
-        return f"{type(self).__name__}\nMessage: {self.message}\nFix?: {self.fix}"
+        exception_name = type(self).__name__
+
+        if self.fix:
+            fix = f"\nFix: {self.fix}"
+        else:
+            fix = ""
+
+        return f"{exception_name}\nError: {self.message}{fix}"
