@@ -4,15 +4,15 @@ import shutil
 
 from aicrowd.notebook.clean import clean_notebook
 from aicrowd.notebook.helpers import (
-    bundle_notebook,
     get_jupyter_notebook_path,
     get_kernel_from_language,
     get_notebook_path,
     write_aicrowd_config,
 )
 from aicrowd.notebook.split import split_notebook
+from aicrowd.notebook import exceptions
 from aicrowd.submission import create_submission as submit_to_aicrowd
-from aicrowd.utils.jupyter import execute_command, is_google_colab_env
+from aicrowd.utils.jupyter import execute_command
 
 SUBMISSION_DIR = os.path.join(os.getcwd(), "submission")
 
@@ -20,7 +20,9 @@ SUBMISSION_DIR = os.path.join(os.getcwd(), "submission")
 def verify_submission():
     print("Validating the submission...")
     if not os.path.exists(SUBMISSION_DIR):
-        raise FileNotFoundError("Please bundle the submission before local evaluation")
+        raise exceptions.SubmissionFileNotFound(
+            "Please bundle the submission before local evaluation"
+        )
     with open(os.path.join(SUBMISSION_DIR, "aicrowd.json")) as fp:
         config = json.load(fp)
     nbconvert_cmd = "jupyter nbconvert --to notebook --ExecutePreprocessor.kernel_name={} --execute {}/{}"
@@ -28,7 +30,7 @@ def verify_submission():
     for notebook in ["install.ipynb", "predict.ipynb"]:
         print(f"Executing {notebook}...")
         if execute_command(nbconvert_cmd.format(kernel, SUBMISSION_DIR, notebook)) != 0:
-            raise RuntimeError(f"{notebook} failed to execute")
+            raise exceptions.LocalEvaluationError(f"{notebook} failed to execute")
 
 
 def bundle_submission(
@@ -38,7 +40,7 @@ def bundle_submission(
 ):
     # Make sure that assets dir is a direct child of current dir
     if os.path.basename(assets_dir) != assets_dir:
-        raise NameError(
+        raise exceptions.AssetsDirectoryError(
             "Assets directory should be a direct part of the current directory"
         )
     if not os.path.exists(assets_dir):
@@ -47,7 +49,7 @@ def bundle_submission(
     if os.listdir(assets_dir) == 0:
         print("WARNING: Assets directory is empty")
 
-    print(f"Using notebook: {get_jupyter_notebook_path()} for submission...")
+    print(f"Using notebook: {get_notebook_path()} for submission...")
 
     # Remove existing files from submission directoru
     if os.path.exists(SUBMISSION_DIR):
