@@ -7,10 +7,10 @@ import os
 import re
 import shutil
 from pathlib import Path
-from typing import Tuple, List, Dict, Any
+from typing import Any, Dict, List, Tuple
+from urllib.parse import unquote
 
 import requests
-from urllib.parse import unquote
 from requests_toolbelt import MultipartEncoderMonitor
 from rich import box
 from rich.console import Console
@@ -29,18 +29,23 @@ from rich.table import Table
 from aicrowd.challenge.helpers import must_get_api_key, parse_cli_challenge
 
 # pylint: enable=unused-import
-from aicrowd.constants import RAILS_API_ENDPOINT, RAILS_HOST
-from aicrowd.utils.jupyter import (
-    is_jupyter,
-    is_google_colab_env,
-    mount_google_drive,
-    get_aicrowd_config,
-)
-from aicrowd.utils.utils import zip_fs_path
+from aicrowd.constants import RAILS_HOST
 from aicrowd.submission.exceptions import (
+    ChallengeNotFoundException,
     SubmissionFileException,
     SubmissionUploadException,
 )
+from aicrowd.utils.jupyter import (
+    get_aicrowd_config,
+    is_google_colab_env,
+    is_jupyter,
+    mount_google_drive,
+)
+from aicrowd.utils.utils import zip_fs_path
+from aicrowd_api.submission import (
+    create_rails_submission,
+    get_submission_upload_details,
+)
 
 
 def calculate_min_table_width(table: Table):
@@ -50,7 +55,11 @@ def calculate_min_table_width(table: Table):
     Args:
         table: rich table
     """
-    width = sum(table._calculate_column_widths(Console(), 200)) + table._extra_width
+    console = Console(width=200)
+    width = (
+        sum(table._calculate_column_widths(console, console.options))
+        + table._extra_width
+    )
     term_width = shutil.get_terminal_size().columns
     return max(width, term_width)
 
@@ -68,12 +77,7 @@ def get_upload_details(challenge_slug: str, api_key: str) -> Tuple[dict, bool]:
     """
     log = logging.getLogger()
 
-    r = requests.get(
-        f"{RAILS_API_ENDPOINT}/submissions",
-        params={"challenge_id": challenge_slug},
-        headers={"Authorization": f"Token token={api_key}"},
-        allow_redirects=False,
-    )
+    r = get_submission_upload_details(api_key, challenge_slug)
 
     # temporary hack until /api stops redirecting
     if r.status_code // 100 == 3:
@@ -84,12 +88,9 @@ def get_upload_details(challenge_slug: str, api_key: str) -> Tuple[dict, bool]:
             redirected_to = redirected_to[len(expected_redirect) :]
         else:
             # got redirected to a weird place
-            logging.error(
-                "Unexpected redirect location: %s\nExpected %s",
-                redirected_to,
-                expected_redirect,
+            raise ChallengeNotFoundException(
+                f"Unexpected redirect location: {redirected_to}"
             )
-            return {}, False
 
         challenge_problem = re.match(
             r"/challenges/([^/]*)/problems/([^/]*)/.*", redirected_to
@@ -113,9 +114,12 @@ def get_upload_details(challenge_slug: str, api_key: str) -> Tuple[dict, bool]:
             return resp, False
 
         return resp.get("data"), True
-    except Exception as e:
-        log.error("Error while extracting details: %s", e)
-        return {}, False
+    except json.JSONDecodeError as e:
+        log.error("Error while extracting details from API request: %s", e)
+        raise ChallengeNotFoundException(
+            "There was some error in contacting AIcrowd servers",
+            "Please increase verbosity to get more details",
+        ) from e
 
 
 class S3Uploader:
@@ -242,21 +246,21 @@ def notify_rails_upload(
         }
     )
 
-    r = requests.post(
-        f"{RAILS_API_ENDPOINT}/submissions",
-        json=payload,
-        headers={"Authorization": f"Token token={api_key}"},
-    )
+    r = create_rails_submission(api_key, payload)
 
     if not r.ok:
         log.error("Request to API failed\nReason: %s\nMessage: %s", r.reason, r.text)
-        return {}
+        raise SubmissionUploadException(
+            f"Couldn't decode response from AIcrowd servers. {r.reason}", r.text
+        )
 
     try:
         return r.json()
-    except Exception as e:
+    except json.JSONDecodeError as e:
         log.error("Couldn't json-decode rails response")
-        return {}
+        raise SubmissionUploadException(
+            "Couldn't decode response from AIcrowd servers"
+        ) from e
 
 
 def print_submission_links(challenge_slug: str, problem_slug: str, submission_id: int):
@@ -427,7 +431,7 @@ def zip_jupyter_notebook(
     notebook_path = get_jupyter_notebook_path()
     cleaned_nb = pop_source_line(
         os.path.join(notebook_path),
-        ['API_KEY(\s+)?=(\s+)?".+"'],
+        [r'API_KEY(\s+)?=(\s+)?".+"'],
     )
     with open(submission_notebook_path, "w") as fp:
         json.dump(cleaned_nb, fp)
@@ -475,7 +479,7 @@ def zip_colab_notebook(target_zip_path: str):
         os.path.join(
             mount_path, "My Drive", "Colab Notebooks", get_colab_notebook_name()
         ),
-        ['API_KEY(\s+)?=(\s+)?".+"'],
+        [r'API_KEY(\s+)?=(\s+)?".+"'],
     )
     with open(submission_notebook_path, "w") as fp:
         json.dump(cleaned_nb, fp)
@@ -531,7 +535,8 @@ def check_session_count(sesssion_info):
         raise EnvironmentError("Please start the notebook with a kernel")
     if len(sesssion_info) > 1:
         raise EnvironmentError(
-            "Found more than one kernel running. Please close other notebooks and kernels and try again."
+            "Found more than one kernel running."
+            "Please close other notebooks and kernels and try again."
         )
 
 
